.. beluga documentation master file, created by
   sphinx-quickstart on Tue Mar  6 23:26:39 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to beluga's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2

   install.rst
   testproblem.rst
   problemsetup.rst
   features.rst
   unittests.rst
   nomenclature.rst
   modules/ivpsol.rst
   modules/bvpsol.rst
   modules/continuation.rst
   modules/optimlib.rst
   modules/codegen.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
